==> ag_1.16.1.tar.gz: ag/man/agPMID2PROBE.Rd <==
\name{agPMID2PROBE}
\alias{agPMID2PROBE}
\title{Map between PubMed Identifiers and Manufacturer Identifiers}
\description{
  agPMID2PROBE is an R environment that provides mappings between
  PubMed identifiers and manufacturer identifiers.
}
\details{
  Each PubMed identifier is mapped to a named vector of manufacturer identifiers. The
  name represents the PubMed identifier and the vector contains all manufacturer
  identifiers that are represented by that PubMed identifier. The length of the vector
  may be one or longer, depending on how many manufacturer identifiers are
  mapped to a given PubMed identifier.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed identifier. The pubmed function of
  annotate can also be used for the same purpose
  
  Mappings were based on data provided by:
  
  Tair: \\url{ftp://ftp.arabidopsis.org/home/tair/Microarrays/Affymetrix/affy\_AG\_array\_elements-2006-07-14.txt}
Tair: \\url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR\_sequenced\_genes}
Tair: \\url{ftp://ftp.arabidopsis.org/home/tair/User\_Requests/LocusPublished.02022007}
Built: N/A 
  
  Package built Thu Mar 15 17:42:16 2007
}

\examples{
    # Convert the environment to a list
    xx <- as.list(agPMID2PROBE)
    if(length(xx) > 0){
        # The probe identifiers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && require(annotate)){
            # Gets article information as XML files for a PubMed id
            xmls <- pubmed(names(xx)[1], disp = "data")
            # Views article information using a browser
            pubmed(names(xx)[1], disp = "browser")
        }
    }
}

\keyword{datasets}

==> ag_2.2.0.tar.gz: ag/man/agPMID2PROBE.Rd <==
\name{agPMID2PROBE}
\alias{agPMID2PROBE}
\title{Map between PubMed Identifiers and Manufacturer Identifiers}
\description{
  agPMID2PROBE is an R environment that provides mappings between
  PubMed identifiers and manufacturer identifiers.
}
\details{
  Each PubMed identifier is mapped to a named vector of manufacturer identifiers. The
  name represents the PubMed identifier and the vector contains all manufacturer
  identifiers that are represented by that PubMed identifier. The length of the vector
  may be one or longer, depending on how many manufacturer identifiers are
  mapped to a given PubMed identifier.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed identifier. The pubmed function of
  annotate can also be used for the same purpose
  
  Mappings were based on data provided by:
  
  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Microarrays/Affymetrix/affy_AG_array_elements-2006-07-14.txt}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/User_Requests/LocusPublished.02022007}
Built: N/A 
  
  Package built Fri Aug 24 17:42:16 2007
}

\examples{
    # Convert the environment to a list
    xx <- as.list(agPMID2PROBE)
    if(length(xx) > 0){
        # The probe identifiers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && require(annotate)){
            # Gets article information as XML files for a PubMed id
            xmls <- pubmed(names(xx)[1], disp = "data")
            # Views article information using a browser
            pubmed(names(xx)[1], disp = "browser")
        }
    }
}

\keyword{datasets}
